Method: Aws::DAX::Types::CreateParameterGroupRequest#parameter_group_name

Defined in:
lib/aws-sdk-dax/types.rb

#parameter_group_nameString

The name of the parameter group to apply to all of the clusters in this replication group.

Returns:

  • (String)


351
352
353
354
355
356
# File 'lib/aws-sdk-dax/types.rb', line 351

class CreateParameterGroupRequest < Struct.new(
  :parameter_group_name,
  :description)
  SENSITIVE = []
  include Aws::Structure
end