Class: Aws::DAX::Types::Event

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-dax/types.rb

Overview

Represents a single occurrence of something interesting within the system. Some examples of events are creating a DAX cluster, adding or removing a node, or rebooting a node.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dateTime

The date and time when the event occurred.



884
885
886
887
888
889
890
891
# File 'lib/aws-sdk-dax/types.rb', line 884

class Event < Struct.new(
  :source_name,
  :source_type,
  :message,
  :date)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

A user-defined message associated with the event.



884
885
886
887
888
889
890
891
# File 'lib/aws-sdk-dax/types.rb', line 884

class Event < Struct.new(
  :source_name,
  :source_type,
  :message,
  :date)
  SENSITIVE = []
  include Aws::Structure
end

#source_nameString

The source of the event. For example, if the event occurred at the node level, the source would be the node ID.



884
885
886
887
888
889
890
891
# File 'lib/aws-sdk-dax/types.rb', line 884

class Event < Struct.new(
  :source_name,
  :source_type,
  :message,
  :date)
  SENSITIVE = []
  include Aws::Structure
end

#source_typeString

Specifies the origin of this event - a cluster, a parameter group, a node ID, etc.



884
885
886
887
888
889
890
891
# File 'lib/aws-sdk-dax/types.rb', line 884

class Event < Struct.new(
  :source_name,
  :source_type,
  :message,
  :date)
  SENSITIVE = []
  include Aws::Structure
end