Class: Aws::DAX::Types::Node

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-dax/types.rb

Overview

Represents an individual node within a DAX cluster.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availability_zoneString

The Availability Zone (AZ) in which the node has been deployed.



1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
# File 'lib/aws-sdk-dax/types.rb', line 1064

class Node < Struct.new(
  :node_id,
  :endpoint,
  :node_create_time,
  :availability_zone,
  :node_status,
  :parameter_group_status)
  SENSITIVE = []
  include Aws::Structure
end

#endpointTypes::Endpoint

The endpoint for the node, consisting of a DNS name and a port number. Client applications can connect directly to a node endpoint, if desired (as an alternative to allowing DAX client software to intelligently route requests and responses to nodes in the DAX cluster.



1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
# File 'lib/aws-sdk-dax/types.rb', line 1064

class Node < Struct.new(
  :node_id,
  :endpoint,
  :node_create_time,
  :availability_zone,
  :node_status,
  :parameter_group_status)
  SENSITIVE = []
  include Aws::Structure
end

#node_create_timeTime

The date and time (in UNIX epoch format) when the node was launched.



1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
# File 'lib/aws-sdk-dax/types.rb', line 1064

class Node < Struct.new(
  :node_id,
  :endpoint,
  :node_create_time,
  :availability_zone,
  :node_status,
  :parameter_group_status)
  SENSITIVE = []
  include Aws::Structure
end

#node_idString

A system-generated identifier for the node.



1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
# File 'lib/aws-sdk-dax/types.rb', line 1064

class Node < Struct.new(
  :node_id,
  :endpoint,
  :node_create_time,
  :availability_zone,
  :node_status,
  :parameter_group_status)
  SENSITIVE = []
  include Aws::Structure
end

#node_statusString

The current status of the node. For example: available.



1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
# File 'lib/aws-sdk-dax/types.rb', line 1064

class Node < Struct.new(
  :node_id,
  :endpoint,
  :node_create_time,
  :availability_zone,
  :node_status,
  :parameter_group_status)
  SENSITIVE = []
  include Aws::Structure
end

#parameter_group_statusString

The status of the parameter group associated with this node. For example, in-sync.



1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
# File 'lib/aws-sdk-dax/types.rb', line 1064

class Node < Struct.new(
  :node_id,
  :endpoint,
  :node_create_time,
  :availability_zone,
  :node_status,
  :parameter_group_status)
  SENSITIVE = []
  include Aws::Structure
end