Class: Aws::DAX::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::DAX::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-dax/client.rb
Overview
An API client for DAX. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::DAX::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_cluster(params = {}) ⇒ Types::CreateClusterResponse
Creates a DAX cluster.
-
#create_parameter_group(params = {}) ⇒ Types::CreateParameterGroupResponse
Creates a new parameter group.
-
#create_subnet_group(params = {}) ⇒ Types::CreateSubnetGroupResponse
Creates a new subnet group.
-
#decrease_replication_factor(params = {}) ⇒ Types::DecreaseReplicationFactorResponse
Removes one or more nodes from a DAX cluster.
-
#delete_cluster(params = {}) ⇒ Types::DeleteClusterResponse
Deletes a previously provisioned DAX cluster.
-
#delete_parameter_group(params = {}) ⇒ Types::DeleteParameterGroupResponse
Deletes the specified parameter group.
-
#delete_subnet_group(params = {}) ⇒ Types::DeleteSubnetGroupResponse
Deletes a subnet group.
-
#describe_clusters(params = {}) ⇒ Types::DescribeClustersResponse
Returns information about all provisioned DAX clusters if no cluster identifier is specified, or about a specific DAX cluster if a cluster identifier is supplied.
-
#describe_default_parameters(params = {}) ⇒ Types::DescribeDefaultParametersResponse
Returns the default system parameter information for the DAX caching software.
-
#describe_events(params = {}) ⇒ Types::DescribeEventsResponse
Returns events related to DAX clusters and parameter groups.
-
#describe_parameter_groups(params = {}) ⇒ Types::DescribeParameterGroupsResponse
Returns a list of parameter group descriptions.
-
#describe_parameters(params = {}) ⇒ Types::DescribeParametersResponse
Returns the detailed parameter list for a particular parameter group.
-
#describe_subnet_groups(params = {}) ⇒ Types::DescribeSubnetGroupsResponse
Returns a list of subnet group descriptions.
-
#increase_replication_factor(params = {}) ⇒ Types::IncreaseReplicationFactorResponse
Adds one or more nodes to a DAX cluster.
-
#list_tags(params = {}) ⇒ Types::ListTagsResponse
List all of the tags for a DAX cluster.
-
#reboot_node(params = {}) ⇒ Types::RebootNodeResponse
Reboots a single node of a DAX cluster.
-
#tag_resource(params = {}) ⇒ Types::TagResourceResponse
Associates a set of tags with a DAX resource.
-
#untag_resource(params = {}) ⇒ Types::UntagResourceResponse
Removes the association of tags from a DAX resource.
-
#update_cluster(params = {}) ⇒ Types::UpdateClusterResponse
Modifies the settings for a DAX cluster.
-
#update_parameter_group(params = {}) ⇒ Types::UpdateParameterGroupResponse
Modifies the parameters of a parameter group.
-
#update_subnet_group(params = {}) ⇒ Types::UpdateSubnetGroupResponse
Modifies an existing subnet group.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-dax/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1867 1868 1869 |
# File 'lib/aws-sdk-dax/client.rb', line 1867 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1870 1871 1872 |
# File 'lib/aws-sdk-dax/client.rb', line 1870 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1840 1841 1842 1843 1844 1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 |
# File 'lib/aws-sdk-dax/client.rb', line 1840 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::DAX') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-dax' context[:gem_version] = '1.87.0' Seahorse::Client::Request.new(handlers, context) end |
#create_cluster(params = {}) ⇒ Types::CreateClusterResponse
Creates a DAX cluster. All nodes in the cluster run the same DAX caching software.
688 689 690 691 |
# File 'lib/aws-sdk-dax/client.rb', line 688 def create_cluster(params = {}, = {}) req = build_request(:create_cluster, params) req.send_request() end |
#create_parameter_group(params = {}) ⇒ Types::CreateParameterGroupResponse
Creates a new parameter group. A parameter group is a collection of parameters that you apply to all of the nodes in a DAX cluster.
723 724 725 726 |
# File 'lib/aws-sdk-dax/client.rb', line 723 def create_parameter_group(params = {}, = {}) req = build_request(:create_parameter_group, params) req.send_request() end |
#create_subnet_group(params = {}) ⇒ Types::CreateSubnetGroupResponse
Creates a new subnet group.
769 770 771 772 |
# File 'lib/aws-sdk-dax/client.rb', line 769 def create_subnet_group(params = {}, = {}) req = build_request(:create_subnet_group, params) req.send_request() end |
#decrease_replication_factor(params = {}) ⇒ Types::DecreaseReplicationFactorResponse
Removes one or more nodes from a DAX cluster.
<note markdown=“1”> You cannot use ‘DecreaseReplicationFactor` to remove the last node in a DAX cluster. If you need to do this, use `DeleteCluster` instead.
</note>
849 850 851 852 |
# File 'lib/aws-sdk-dax/client.rb', line 849 def decrease_replication_factor(params = {}, = {}) req = build_request(:decrease_replication_factor, params) req.send_request() end |
#delete_cluster(params = {}) ⇒ Types::DeleteClusterResponse
Deletes a previously provisioned DAX cluster. DeleteCluster deletes all associated nodes, node endpoints and the DAX cluster itself. When you receive a successful response from this action, DAX immediately begins deleting the cluster; you cannot cancel or revert this action.
915 916 917 918 |
# File 'lib/aws-sdk-dax/client.rb', line 915 def delete_cluster(params = {}, = {}) req = build_request(:delete_cluster, params) req.send_request() end |
#delete_parameter_group(params = {}) ⇒ Types::DeleteParameterGroupResponse
Deletes the specified parameter group. You cannot delete a parameter group if it is associated with any DAX clusters.
944 945 946 947 |
# File 'lib/aws-sdk-dax/client.rb', line 944 def delete_parameter_group(params = {}, = {}) req = build_request(:delete_parameter_group, params) req.send_request() end |
#delete_subnet_group(params = {}) ⇒ Types::DeleteSubnetGroupResponse
Deletes a subnet group.
<note markdown=“1”> You cannot delete a subnet group if it is associated with any DAX clusters.
</note>
977 978 979 980 |
# File 'lib/aws-sdk-dax/client.rb', line 977 def delete_subnet_group(params = {}, = {}) req = build_request(:delete_subnet_group, params) req.send_request() end |
#describe_clusters(params = {}) ⇒ Types::DescribeClustersResponse
Returns information about all provisioned DAX clusters if no cluster identifier is specified, or about a specific DAX cluster if a cluster identifier is supplied.
If the cluster is in the CREATING state, only cluster level information will be displayed until all of the nodes are successfully provisioned.
If the cluster is in the DELETING state, only cluster level information will be displayed.
If nodes are currently being added to the DAX cluster, node endpoint information and creation time for the additional nodes will not be displayed until they are completely provisioned. When the DAX cluster state is available, the cluster is ready for use.
If nodes are currently being removed from the DAX cluster, no endpoint information for the removed nodes is displayed.
1076 1077 1078 1079 |
# File 'lib/aws-sdk-dax/client.rb', line 1076 def describe_clusters(params = {}, = {}) req = build_request(:describe_clusters, params) req.send_request() end |
#describe_default_parameters(params = {}) ⇒ Types::DescribeDefaultParametersResponse
Returns the default system parameter information for the DAX caching software.
1131 1132 1133 1134 |
# File 'lib/aws-sdk-dax/client.rb', line 1131 def describe_default_parameters(params = {}, = {}) req = build_request(:describe_default_parameters, params) req.send_request() end |
#describe_events(params = {}) ⇒ Types::DescribeEventsResponse
Returns events related to DAX clusters and parameter groups. You can obtain events specific to a particular DAX cluster or parameter group by providing the name as a parameter.
By default, only the events occurring within the last 24 hours are returned; however, you can retrieve up to 14 days’ worth of events if necessary.
1207 1208 1209 1210 |
# File 'lib/aws-sdk-dax/client.rb', line 1207 def describe_events(params = {}, = {}) req = build_request(:describe_events, params) req.send_request() end |
#describe_parameter_groups(params = {}) ⇒ Types::DescribeParameterGroupsResponse
Returns a list of parameter group descriptions. If a parameter group name is specified, the list will contain only the descriptions for that group.
1257 1258 1259 1260 |
# File 'lib/aws-sdk-dax/client.rb', line 1257 def describe_parameter_groups(params = {}, = {}) req = build_request(:describe_parameter_groups, params) req.send_request() end |
#describe_parameters(params = {}) ⇒ Types::DescribeParametersResponse
Returns the detailed parameter list for a particular parameter group.
1320 1321 1322 1323 |
# File 'lib/aws-sdk-dax/client.rb', line 1320 def describe_parameters(params = {}, = {}) req = build_request(:describe_parameters, params) req.send_request() end |
#describe_subnet_groups(params = {}) ⇒ Types::DescribeSubnetGroupsResponse
Returns a list of subnet group descriptions. If a subnet group name is specified, the list will contain only the description of that group.
1377 1378 1379 1380 |
# File 'lib/aws-sdk-dax/client.rb', line 1377 def describe_subnet_groups(params = {}, = {}) req = build_request(:describe_subnet_groups, params) req.send_request() end |
#increase_replication_factor(params = {}) ⇒ Types::IncreaseReplicationFactorResponse
Adds one or more nodes to a DAX cluster.
1451 1452 1453 1454 |
# File 'lib/aws-sdk-dax/client.rb', line 1451 def increase_replication_factor(params = {}, = {}) req = build_request(:increase_replication_factor, params) req.send_request() end |
#list_tags(params = {}) ⇒ Types::ListTagsResponse
List all of the tags for a DAX cluster. You can call ‘ListTags` up to 10 times per second, per account.
1490 1491 1492 1493 |
# File 'lib/aws-sdk-dax/client.rb', line 1490 def (params = {}, = {}) req = build_request(:list_tags, params) req.send_request() end |
#reboot_node(params = {}) ⇒ Types::RebootNodeResponse
Reboots a single node of a DAX cluster. The reboot action takes place as soon as possible. During the reboot, the node status is set to REBOOTING.
<note markdown=“1”> ‘RebootNode` restarts the DAX engine process and does not remove the contents of the cache.
</note>
1564 1565 1566 1567 |
# File 'lib/aws-sdk-dax/client.rb', line 1564 def reboot_node(params = {}, = {}) req = build_request(:reboot_node, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Types::TagResourceResponse
Associates a set of tags with a DAX resource. You can call ‘TagResource` up to 5 times per second, per account.
1604 1605 1606 1607 |
# File 'lib/aws-sdk-dax/client.rb', line 1604 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Types::UntagResourceResponse
Removes the association of tags from a DAX resource. You can call ‘UntagResource` up to 5 times per second, per account.
1640 1641 1642 1643 |
# File 'lib/aws-sdk-dax/client.rb', line 1640 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_cluster(params = {}) ⇒ Types::UpdateClusterResponse
Modifies the settings for a DAX cluster. You can use this action to change one or more cluster configuration parameters by specifying the parameters and the new values.
1736 1737 1738 1739 |
# File 'lib/aws-sdk-dax/client.rb', line 1736 def update_cluster(params = {}, = {}) req = build_request(:update_cluster, params) req.send_request() end |
#update_parameter_group(params = {}) ⇒ Types::UpdateParameterGroupResponse
Modifies the parameters of a parameter group. You can modify up to 20 parameters in a single request by submitting a list parameter name and value pairs.
1786 1787 1788 1789 |
# File 'lib/aws-sdk-dax/client.rb', line 1786 def update_parameter_group(params = {}, = {}) req = build_request(:update_parameter_group, params) req.send_request() end |
#update_subnet_group(params = {}) ⇒ Types::UpdateSubnetGroupResponse
Modifies an existing subnet group.
1831 1832 1833 1834 |
# File 'lib/aws-sdk-dax/client.rb', line 1831 def update_subnet_group(params = {}, = {}) req = build_request(:update_subnet_group, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1860 1861 1862 |
# File 'lib/aws-sdk-dax/client.rb', line 1860 def waiter_names [] end |